@@ -1,7 +1,5 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4 -*-
-
 /*
- *  PaperBox - category-editor.cc
+ *  Paperbox - category-editor.cc
  *
  *  Copyright (C) 2008 Marko Anastasov
  *
@@ -37,7 +35,7 @@ namespace paperbox {
 
     using std::list;
     using std::vector;
-    using boost::shared_ptr;
+    using std::tr1::shared_ptr;
 
     const int DEFAULT_WIDTH = 500;
     const int DEFAULT_HEIGHT = 375; // try to keep the ratio 4:3
@@ -146,8 +144,8 @@ namespace paperbox {
 
         // get notified about new tags through new documents
         // TODO: what about signals for tags added/removed?
-        Browser::instance()->signal_new_document().connect(
-            sigc::mem_fun(*this, &CategoryEditor::on_new_document));
+        Browser::instance()->signal_document_retrieved().connect(
+            sigc::mem_fun(*this, &CategoryEditor::on_document_retrieved));
 
         tag_cloud_.signal_tag_clicked().connect(
             sigc::mem_fun(*this, &CategoryEditor::on_tag_clicked));
@@ -285,7 +283,7 @@ namespace paperbox {
     }
 
     void
-    CategoryEditor::on_new_document(const shared_ptr<Document>& doc)
+    CategoryEditor::on_document_retrieved(const shared_ptr<Document>& doc)
     {
         static_cast<DocumentTagCloudModel*>(
             tag_cloud_model_.get())->update_tags(doc);
